@@ -32,7 +32,6 @@
 #include "bluetooth-filter-widget.h"
 #include "bluetooth-client.h"
 #include "gnome-bluetooth-enum-types.h"
-#include "seahorse-bind.h"
 
 #define BLUETOOTH_FILTER_WIDGET_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), \
 						BLUETOOTH_TYPE_FILTER_WIDGET, BluetoothFilterWidgetPrivate))
@@ -52,9 +51,6 @@ struct _BluetoothFilterWidgetPrivate {
 	int device_category_filter;
 	char *device_service_filter;
 
-	/* See bluetooth_filter_widget_bind_chooser () */
-	gpointer bindings[8];
-
 	guint show_device_type : 1;
 	guint show_device_category : 1;
 };
@@ -180,19 +176,15 @@ bluetooth_filter_widget_set_title (BluetoothFilterWidget *self, gchar *title)
 static void
 bluetooth_filter_widget_bind_chooser_single (BluetoothFilterWidget *self,
 					     BluetoothChooser *chooser,
-					     const char *property,
-					     guint *i)
+					     const char *property)
 {
-	BluetoothFilterWidgetPrivate *priv = BLUETOOTH_FILTER_WIDGET_GET_PRIVATE(self);
-
 	/* NOTE: We are binding the chooser as the source so that all of it's
 	 * properties are pushed to the filter.
-	 * Remember the bindings so we can unbind them later on */
-	priv->bindings[*i] = seahorse_bind_property (property, (gpointer) chooser,
-						    property, (gpointer) self);
-	priv->bindings[(*i)++] = seahorse_bind_property (property, (gpointer) self,
-		 				      property, (gpointer) chooser);
-	(*i)++;
+	 * The bindings will be automatically removed when one of the
+	 * objects go away */
+	g_object_bind_property ((gpointer) chooser, property,
+				(gpointer) self, property,
+				G_BINDING_BIDIRECTIONAL);
 }
 
 /**
@@ -209,13 +201,10 @@ bluetooth_filter_widget_bind_chooser_single (BluetoothFilterWidget *self,
 void
 bluetooth_filter_widget_bind_filter (BluetoothFilterWidget *self, BluetoothChooser *chooser)
 {
-	guint i;
-
-	i = 0;
-	bluetooth_filter_widget_bind_chooser_single (self, chooser, "device-type-filter", &i);
-	bluetooth_filter_widget_bind_chooser_single (self, chooser, "device-category-filter", &i);
-	bluetooth_filter_widget_bind_chooser_single (self, chooser, "show-device-type", &i);
-	bluetooth_filter_widget_bind_chooser_single (self, chooser, "show-device-category", &i);
+	bluetooth_filter_widget_bind_chooser_single (self, chooser, "device-type-filter");
+	bluetooth_filter_widget_bind_chooser_single (self, chooser, "device-category-filter");
+	bluetooth_filter_widget_bind_chooser_single (self, chooser, "show-device-type");
+	bluetooth_filter_widget_bind_chooser_single (self, chooser, "show-device-category");
 }
 
 static void
@@ -260,7 +249,7 @@ bluetooth_filter_widget_init(BluetoothFilterWidget *self)
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	priv->device_category_label = label;
 
-	priv->device_category = gtk_combo_box_new_text ();
+	priv->device_category = gtk_combo_box_text_new ();
 	gtk_widget_set_no_show_all (priv->device_category, TRUE);
 	gtk_widget_show (priv->device_category);
 	gtk_table_attach (GTK_TABLE (table), priv->device_category, 1, 2, 1, 2,
@@ -268,8 +257,8 @@ bluetooth_filter_widget_init(BluetoothFilterWidget *self)
 			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
 	gtk_widget_set_tooltip_text (priv->device_category, _("Select the device category to filter"));
 	for (i = 0; i < BLUETOOTH_CATEGORY_NUM_CATEGORIES; i++) {
-		gtk_combo_box_append_text (GTK_COMBO_BOX (priv->device_category),
-					   _(bluetooth_device_category_to_string (i)));
+		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (priv->device_category),
+					        _(bluetooth_device_category_to_string (i)));
 	}
 	g_signal_connect (G_OBJECT (priv->device_category), "changed",
 			  G_CALLBACK (filter_category_changed_cb), self);
@@ -353,18 +342,11 @@ static void
 bluetooth_filter_widget_dispose (GObject *object)
 {
 	BluetoothFilterWidgetPrivate *priv = BLUETOOTH_FILTER_WIDGET_GET_PRIVATE(object);
-	guint i;
 
 	if (priv->chooser) {
 		g_object_unref (priv->chooser);
 		priv->chooser = NULL;
 	}
-	for (i = 0; i < 8; i++) {
-		if (priv->bindings[i] != NULL) {
-			seahorse_bind_disconnect (priv->bindings[i]);
-			priv->bindings[i] = NULL;
-		}
-	}
 
 	G_OBJECT_CLASS(bluetooth_filter_widget_parent_class)->dispose(object);
 }
@@ -480,14 +462,13 @@ bluetooth_filter_widget_class_init (BluetoothFilterWidgetClass *klass)
 
 /**
  * bluetooth_filter_widget_new:
- * @chooser: The #BluetoothChooser to filter
  *
- * Return value: A #BluetoothFilterWidget widget
- * 
  * Creates a new #BluetoothFilterWidget which can be bound to a #BluetoothChooser to
  * control filtering of that #BluetoothChooser.
  * Usually used in conjunction with a #BluetoothChooser which has the "has-internal-filter"
  * property set to FALSE.
+ *
+ * Return value: A #BluetoothFilterWidget widget
  * 
  * Note: Must call bluetooth_filter_widget_bind_filter () to bind the #BluetoothFilterWidget
  * to a #BluetoothChooser.
